# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/alexbrowns/introduction/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/alexbrowns/introduction/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Alexbrowns\\Introduction\\": "packages/alexbrowns/introduction/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Alexbrowns\Introduction\Providers\IntroductionServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Introduction'  => Alexbrowns\Introduction\Facades\Introduction::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Alexbrowns\\IntroductionTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Alexbrowns\Introduction\Providers\IntroductionServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Alexbrowns\Introduction\Providers\IntroductionServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Alexbrowns\Introduction\Providers\IntroductionServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/introduction/{modulename}

**User**

    http://path-to-route-folder/user/introduction/{modulename}

**Public**

    http://path-to-route-folder/introductions


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/introduction/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/introduction/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/introduction/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/introduction/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/introduction/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/introduction/{modulename}/{slug}
    METHOD: GET